@@ -24,7 +24,7 @@
 #define MP4V2_PROJECT_repo_rev        493
 #define MP4V2_PROJECT_repo_date       "2012-05-20 15:16:54 -0700 (Sun, 20 May 2012)"
 #define MP4V2_PROJECT_repo_type       "stable"
-#define MP4V2_PROJECT_build           "Wed May 30 23:57:47 UTC 2018"
+#define MP4V2_PROJECT_build           "Mon Mar 16 00:12:18 UTC 2020"
 
 /*****************************************************************************/
 
